@@ -16,4 +16,7 @@ pub mod proto;
 pub mod client;
 pub mod server;
 pub mod frame;
-pub mod balance;
\ No newline at end of file
+pub mod balance;
+pub mod balance_manager;
+
+pub use balance_manager::*;
\ No newline at end of file
